require 'spec_helper'

describe Crowdkit::Client::Judgments do
  context "show" do
    let(:judgment_id) { 6634 }
    let!(:request_stub) { stub_get("/judgments/#{judgment_id}").to_return(fixture_response("judgments/show.json")) }

    context "requests" do
      it "gets made" do
        client.judgments.get(judgment_id)
        expect(request_stub).to have_been_requested
      end

      it "has find alias" do
        client.judgments.find(judgment_id)
        expect(request_stub).to have_been_requested
      end

      it "blows up without id" do
        expect { client.judgments.get }.to raise_error(Crowdkit::ValidationError)
      end
    end

    context "response" do
      it "parses" do
        expect(client.judgments.get(judgment_id).id).to eq(judgment_id)
      end
    end
  end

  describe "list" do
    let!(:request_stub) { stub_get("/jobs/10/judgments").to_return(fixture_response("judgments/index.json")) }

    context "requests" do
      it "gets made" do
        client.judgments(job_id: 10).list
        expect(request_stub).to have_been_requested
      end

      it "has all alias" do
        client.judgments.all(job_id: 10)
        expect(request_stub).to have_been_requested
      end

      it "blows up without job_id" do
        expect { client.judgments.list }.to raise_error Crowdkit::ValidationError
      end
    end

    context "response" do
      it "parses" do
        expect(client.judgments(job_id: 10).list.length).to eq(3)
      end
    end
  end
end
