require 'spec_helper'

describe Crowdkit::Client::Worksets do
  context "show" do
    let!(:request_stub) { stub_get("/worksets/1").to_return(fixture_response("worksets/show.json")) }

    context "requests" do
      it "gets made" do
        client.worksets.get(1)
        expect(request_stub).to have_been_requested
      end

      it "has find alias" do
        client.worksets.find(1)
        expect(request_stub).to have_been_requested
      end

      it "blows up without id" do
        expect { client.worksets.get }.to raise_error Crowdkit::ValidationError
      end
    end

    context "response" do
      it "parses" do
        expect(client.worksets.get(1).id).to eq(1)
      end
    end
  end

  context "list" do
    let!(:request_stub) { stub_get("/jobs/1/worksets").to_return(fixture_response("worksets/index.json")) }

    context "requests" do
      it "gets made" do
        client.worksets(job_id: 1).list
        expect(request_stub).to have_been_requested
      end

      it "has all alias" do
        client.worksets.all(job_id: 1)
        expect(request_stub).to have_been_requested
      end

      it "blows up without job_id" do
        expect { client.worksets.list }.to raise_error Crowdkit::ValidationError
      end
    end

    context "response" do
      it "parses" do
        expect(client.worksets(job_id: 1).list.length).to eq(2)
      end
    end
  end


  context "statuses" do
    shared_examples_for "statuses" do
      it "requests" do
        expect(request_stub).to have_been_requested
      end

      it "response" do
        expect(client.last_response.status).to eq(204)
      end
    end

    context "flag" do
      it_behaves_like "statuses" do
        let!(:request_stub) { stub_put("/worksets/1/flag").to_return(status: 204) }
        before { client.worksets(workset_id: 1).flag(reason: 'Because') }
      end
    end

    context "deflag" do
      it_behaves_like "statuses" do
        let!(:request_stub) { stub_put("/worksets/1/deflag").to_return(status: 204) }
        before { client.worksets(workset_id: 1).deflag(reason: 'Because') }
      end
    end

    context "reject" do
      it_behaves_like "statuses" do
        let!(:request_stub) { stub_put("/worksets/1/reject").to_return(status: 204) }
        before { client.worksets(workset_id: 1).reject(reason: 'Too bad!') }
      end
    end

    context "approve" do
      it_behaves_like "statuses" do
        let!(:request_stub) { stub_put("/worksets/1/approve").to_return(status: 204) }
        before { client.worksets(workset_id: 1).approve(reason: 'Cool!') }
      end
    end
  end

  context "bonus" do
    let!(:request_stub) { stub_put("/worksets/1/bonus").to_return(status: 204) }
    before { client.worksets(workset_id: 1).bonus(amount: 10) }

    it "requests" do
      expect(request_stub).to have_been_requested
    end

    it "response" do
      expect(client.last_response.status).to eq(204)
    end

    it "blows up without amount" do
      expect { client.worksets(workset_id: 1).bonus }.to raise_error Crowdkit::ValidationError
    end
  end
end