require 'spec_helper'
require 'open-uri'
describe Crowdkit::Client do
  context 'root' do
    let!(:request_stub) { stub_get("").to_return(fixture_response("root.json")) }

    it "requests the resource" do
      client.root
      expect(request_stub).to have_been_requested
    end

    it "provides links" do
      expect(client.root.rels.size).to eq(2)
    end
  end

  context "pagination" do
    let!(:first_page) { stub_get("/jobs").to_return(fixture_response("jobs/search.json", 200, { Link: '<https://api.crowdflower.com/v2/jobs?page=2>; rel="last", <https://api.crowdflower.com/v2/jobs?page=2>; rel="next"'})) }
    let!(:last_page) { stub_get("/jobs?page=2").to_return(fixture_response("jobs/search.json", 200, { Link: '<https://api.crowdflower.com/v2/jobs>; rel="first", <https://api.crowdflower.com/v2/jobs>; rel="prev"'}))}

    it "auto paginates with a block" do
      client.config.auto_paginate = true
      total_jobs = 0
      client.jobs.list { |job| total_jobs += 1 }
      expect(total_jobs).to eq(10)
      expect(first_page).to have_been_requested
      expect(last_page).to have_been_requested
    end

    it "auto paginates without a block" do
      client.config.auto_paginate = true
      expect(client.jobs.list.to_a.length).to eq(10)
    end

    it "auto paginates with options" do
      expect(client.config.auto_paginate).to be_falsey
      expect(client.jobs.list(auto_pagination: true).to_a.length).to eq(10)
      expect(client.auto_pagination).to be_falsey
    end

    it "next page" do
      expect(client.jobs.list.next_page.length).to eq(5)
      expect(last_page).to have_been_requested
    end

    it "prev page" do
      client.jobs.list.next_page.prev_page
      expect(first_page).to have_been_requested.twice
    end

    it "missing page" do
      expect(client.jobs.list.first_page).to be_falsey
    end
  end
end
