require 'simplecov'

module SimpleCov::Configuration
  def clean_filters
    @filters = []
  end
end

SimpleCov.configure do
  clean_filters
  load_profile 'test_frameworks'
end

ENV["COVERAGE"] && SimpleCov.start do
  add_filter "/.rvm/"
end
$LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
$LOAD_PATH.unshift(File.dirname(__FILE__))

require 'rspec'
require 'webmock/rspec'
require 'crowdkit'

WebMock.disable_net_connect!

# Requires supporting files with custom matchers and macros, etc,
# in ./support/ and its subdirectories.
Dir["#{File.dirname(__FILE__)}/support/**/*.rb"].each {|f| require f }

RSpec.configure do |config|
  config.include WebMock::API

  config.before(:each) do
    WebMock.reset!
  end
  config.after(:each) do
    WebMock.reset!
  end
end

def fixture(file)
  File.new(File.join(File.expand_path("../fixtures", __FILE__), '/', file))
end

def fixture_response(file, status = 200, headers = {})
  { body: fixture(file), status: status, headers: { content_type: "application/json; charset=utf-8" }.merge(headers) }
end

[:get,:post,:put,:patch,:delete,:head].each do |method|
  define_method("stub_#{method}") do |path, endpoint = Crowdkit.config.api_endpoint|
    stub_request(method, path.is_a?(String) ? endpoint + path : path)
  end
end
